# url-to-desktop
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/a85c79e5dac14a51883f8de2aa7cd6d9)](https://app.codacy.com/manual/xandao6/url-to-dektop?utm_source=github.com&utm_medium=referral&utm_content=xandao6/url-to-dektop&utm_campaign=Badge_Grade_Dashboard)
[![HitCount](http://hits.dwyl.io/xandao6/url-to-desktop.svg)](http://hits.dwyl.io/xandao6/url-to-desktop)

It is a command line software through which you can convert .url files, used in Windows, into .desktop files used in linux.

---
## Installation
url-to-desktop is available on PyPI. You can install url-to-desktop by pip command: 

```bash
pip3 install url-to-desktop
```

## Usage
<img src="/src/images/before conversion.png"><br>
<img src="/src/images/converting.png"><br>
<img src="/src/images/after conversion.png"><br>

Example -  
To convert in the current directory 
```bash
url-to-desktop
```
To convert in a specific directory
```bash 
url-to-desktop /path/
````

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

## License
[![GitHub](https://img.shields.io/github/license/xandao6/url-to-desktop?style=for-the-badge)](https://github.com/xandao6/url-to-dektop/blob/master/LICENSE)

***If you like the project, support us by star***
